@@ -4,16 +4,22 @@
 
 use std::path::PathBuf;
 
+/// Returns the absolute path to the top-level data directory.
+pub fn data_root() -> PathBuf {
+    PathBuf::from(std::env!("CARGO_MANIFEST_DIR")).join("data")
+}
+
 /// Returns the absolute path to the CLDR JSON root directory.
 pub fn cldr_json_root() -> PathBuf {
-    PathBuf::from(std::env!("CARGO_MANIFEST_DIR"))
-        .join("data")
-        .join("cldr")
+    data_root().join("cldr")
+}
+
+/// Returns the absolute path to the UProps TOML root directory.
+pub fn uprops_toml_root() -> PathBuf {
+    data_root().join("uprops")
 }
 
 /// Returns the absolute path to the ICU4X JSON root directory.
 pub fn icu4x_json_root() -> PathBuf {
-    PathBuf::from(std::env!("CARGO_MANIFEST_DIR"))
-        .join("data")
-        .join("json")
+    data_root().join("json")
 }
